package app.data.entity;

import javax.persistence.*;
import java.util.Objects;

@Entity
@Table(name = "game_info", schema = "public", catalog = "chessleague")
public class GameInfo {
    private Integer id;
    private String chessComId;
    private Game game;
    private String timeControl;
    private String fen;
    private Long endTime;
    private String pgn;
    private Boolean rated;
    private String timeClass;
    private String rules;
    private Integer whiteRating;
    private Integer blackRating;
    private String whiteResult;
    private String blackResult;

    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "id", nullable = false)
    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    @Basic
    @Column(name = "chess_com_id", length = -1)
    public String getChessComId() {
        return chessComId;
    }

    public void setChessComId(String chessComId) {
        this.chessComId = chessComId;
    }

    @Basic
    @Column(name = "time_control", nullable = false)
    public String getTimeControl() {
        return timeControl;
    }

    public void setTimeControl(String format) {
        this.timeControl = format;
    }

    @Basic
    @Column(name = "fen", nullable = false)
    public String getFen() {
        return fen;
    }

    public void setFen(String fen) {
        this.fen = fen;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        GameInfo that = (GameInfo) o;
        return Objects.equals(id, that.id) && Objects.equals(chessComId, that.chessComId) && Objects.equals(timeControl, that.timeControl);
    }

    @Override
    public int hashCode() {
        return Objects.hash(id, chessComId, timeControl);
    }

    @OneToOne(mappedBy = "gameInfo", cascade = CascadeType.DETACH)
    public Game getGame() {
        return game;
    }

    public void setGame(Game game) {
        this.game = game;
    }

    @Basic
    @Column(name = "end_time") // TODO: make not nullable (you need the end times of the first matchday for that...)
    public Long getEndTime() {
        return endTime;
    }

    public void setEndTime(Long endTime) {
        this.endTime = endTime;
    }

    @Basic
    @Column(name = "pgn")
    public String getPgn() {
        return pgn;
    }

    public void setPgn(String pgn) {
        this.pgn = pgn;
    }

    @Basic
    @Column(name = "rated")
    public Boolean getRated() {
        return rated;
    }

    public void setRated(Boolean rated) {
        this.rated = rated;
    }

    @Basic
    @Column(name = "time_class")
    public String getTimeClass() {
        return timeClass;
    }

    public void setTimeClass(String timeClass) {
        this.timeClass = timeClass;
    }

    @Basic
    @Column(name = "rules")
    public String getRules() {
        return rules;
    }

    public void setRules(String rules) {
        this.rules = rules;
    }

    @Basic
    @Column(name = "white_rating")
    public Integer getWhiteRating() {
        return whiteRating;
    }

    public void setWhiteRating(Integer whiteRating) {
        this.whiteRating = whiteRating;
    }

    @Basic
    @Column(name = "black_rating")
    public Integer getBlackRating() {
        return blackRating;
    }

    public void setBlackRating(Integer blackRating) {
        this.blackRating = blackRating;
    }

    @Basic
    @Column(name = "white_result")
    public String getWhiteResult() {
        return whiteResult;
    }

    public void setWhiteResult(String whiteResult) {
        this.whiteResult = whiteResult;
    }

    @Basic
    @Column(name = "black_result")
    public String getBlackResult() {
        return blackResult;
    }

    public void setBlackResult(String blackResult) {
        this.blackResult = blackResult;
    }
}
